Stress-testing

MQSeries Specialist (UK)	c Xephon 1999



package com.dmitri.mqstress;
import com.sun.java.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.util.*;
/**
*   @author Dmitri
*
*   This class prompts for various parameters that are thereafter 
*   used to control the test. To save users the trouble of repeatedly 
*   typing in data, the class persists itself to disk using standard 
*   serialization.
*/
public class MQConstants extends JFrame implements Serializable {

//  The constants
  private JTextField iQueueManagerName = new JTextField();
  private JTextField iHostName = new JTextField();
  private JTextField iChannelName = new JTextField();
  private JTextField iRequestQueueName = new JTextField();
  private JTextField iReplyQueueName = new JTextField();
  private JTextField iMaxMessageLength = new JTextField();
  private JTextField iNumberOfInstances = new JTextField();
  private JTextField iNumberOfRepetitions = new JTextField();
  private JTextField iNumberOfMessages = new JTextField();

//  Arrays of 'textfields' for message details
  private JTextField [] iMessageLenthOrFile;  // The length of a blank 
                                              // message or a file
  private JTextField [] iAcceptableTime;      // Acceptable time
  private JTextField [] iFailureTime;         // Time after which 
                                              // message is deemed to 
                                              // have failed
  private JTextField [] iPaceTime;            // Time used to delay 
                                              // between messages

//  The text that is to be used for messaging.
  private String [] iMessages;

//  Buttons
  private JButton iBtnMessages = new JButton("Messages");
  private JButton iBtnReset = new JButton("Reset");
  private  JButton iBtnOk = new JButton("Ok");

//  Messsage capture dialogue box
  private JDialog iMessagedlg;

  protected static MQConstants cInstance;
  private transient Vector iListeners = new Vector();
  private static final String PERSISTENCY_NAME = "MQConstants.ser";

/**
*   Return the name of the queue manager
*/
  public String getQueueManagerName() {
    return iQueueManagerName.getText();
  }
/**
*   Return the host name
*/
  public String getHostName() {
    return iHostName.getText();
  }
/**
*   Return the channel name
*/
  public String getChannelName() {
    return iChannelName.getText();
  }
/**
*   Return the name of the request queue
*/
  public String getRequestQueueName() {
    return iRequestQueueName.getText();
  }
/**
*   Return the name of the reply queue
*/
  public String getReplyQueueName() {
    return iReplyQueueName.getText();
  }
/**
*   Return the maximum message length
*   Note : no effort is made to validate numeric values entered
*/
  public int getMaximumMessageLength() {
    return Integer.parseInt(iMaxMessageLength.getText());
  }
/**
*   Return the number of instances of the stress tester to run
*   Note : no effort is made to validate numeric values entered
*/
  public int getNumberOfInstances() {
    return Integer.parseInt(iNumberOfInstances.getText());
  }
/**
*   Return the number of repetitions to make
*   Note : no effort is made to validate numeric values entered
*/
  public int getNumberOfRepetitions() {
    return Integer.parseInt(iNumberOfRepetitions.getText());
  }
/**
*   Return the number of messages requested
*/
  public int getNumberOfMesages() {
    try {
      return Integer.parseInt(iNumberOfMessages.getText());
    } catch (NumberFormatException ex) {}
    return 0;
  }
/**
*   Return the time (in milliseconds) that is specified as acceptable
*   Note : no effort is made to validate numeric values entered
*/
  public int getAcceptableTime(int index) {
    return Integer.parseInt(iAcceptableTime[index].getText());
  }
/**
*   Return the time (in milliseconds) that represents a failure
*   Note : no effort is made to validate numeric values entered
*/
  public int getFailureTime(int index) {
    return Integer.parseInt(iFailureTime[index].getText());
  }
/**
*   Return the time (in milliseconds) that to be used to pace
*   MQ polling
*   Note : no effort is made to validate numeric values entered
*/
  public int getPaceTime(int index) {
    return Integer.parseInt(iFailureTime[index].getText());
  }
/**
*   Return the message specified by the index supplied
*/
  public String getMessage(int index) {
    return iMessages[index];
  }

/**
*   Standard singleton pattern constructor that takes care of the
*   capture of runtime parameters
*/
  protected MQConstants() {

    super("MQPing Constants");
    setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);

    JPanel contents = new JPanel();
    getContentPane().add(contents);
    contents.setBorder(BorderFactory.createEmptyBorder(15,15,15,15));
    contents.setLayout(new BorderLayout());

    JPanel middle = new JPanel();
    middle.setLayout(new GridLayout(10, 2, 10, 10));  // Panel to 
                                               // capture constants
    contents.add(middle);

    middle.add(new JLabel("Queue Manager Name:"));
    middle.add(iQueueManagerName);
    middle.add(new JLabel("Host Name:"));
    middle.add(iHostName);
    middle.add(new JLabel("Client Channel Name:"));
    middle.add(iChannelName);
    middle.add(new JLabel("Request Queue Name:"));
    middle.add(iRequestQueueName);
    middle.add(new JLabel("Reply Queue Name:"));
    middle.add(iReplyQueueName);
    middle.add(new JLabel("Max message Length:"));
    middle.add(iMaxMessageLength);
    middle.add(new JLabel("Number of Instances:"));
    middle.add(iNumberOfInstances);
    middle.add(new JLabel("Number of Repetitions:"));
    middle.add(iNumberOfRepetitions);
    middle.add(new JLabel("Number of Messages:"));
    middle.add(iNumberOfMessages);

    JPanel buttons = new JPanel();
    contents.add(buttons, BorderLayout.SOUTH);
    iBtnOk.setEnabled(false);
    buttons.setLayout(new FlowLayout());
    buttons.add(iBtnMessages);
    buttons.add(iBtnReset);
    buttons.add(iBtnOk);

    addListeners();
    pack();

  }

/**
*   Handle hiding of the prompter frame and persisting data, which
*   is also a convenient point at which to calculate messages
*/
  private void closeEvent() {
    try {
      ObjectOutputStream oos = new ObjectOutputStream(new 
                                 FileOutputStream(PERSISTENCY_NAME));
      oos.writeObject(this);
      oos.flush();
      oos.close();
    } catch (IOException ex) {
      ex.printStackTrace();
    }

    iMessages = new String [iMessageLenthOrFile.length];

    for (int i = 0; i < iMessageLenthOrFile.length; i++) {

      try {
        int buffLen = 
                 Integer.parseInt(iMessageLenthOrFile[i].getText());
        char [] buffer = new char [buffLen];
        for (int j = 0; j < buffLen; j++) buffer[j] = ' ';
        iMessages[i] = new String(buffer);

      } catch (NumberFormatException ex) { // The user has 
                                           // specified a filename

        try {
          BufferedReader reader = new BufferedReader(
            new FileReader( iMessageLenthOrFile[i].getText() ) );
          iMessages[i] = reader.readLine();
        } catch(IOException ioex) {
          System.out.println(ioex);
          System.out.println("Message length set to 1");
          iMessages[i] = " ";
        }
      }
    }
    setVisible(false);
        notifyConstantsListeners();
  }

/**
*   Adds appropriate inner classes for listening to buttons
*/
  private void addListeners() {

    iListeners = new Vector();
    iBtnMessages.addActionListener(new ActionListener() {

      public void actionPerformed(ActionEvent e) {
        setUpMessages();
        iBtnOk.setEnabled(true);
      }
    });

    iBtnReset.addActionListener(new ActionListener() {

      public void actionPerformed(ActionEvent e) {
        setVisible(false);
        cInstance = new MQConstants();
        cInstance.setVisible(true);
      }
    });

    iBtnOk.addActionListener(new ActionListener() {

      public void actionPerformed(ActionEvent e) {
        closeEvent();
      }
    });
  }
/**
*   Sets up the visual fields to capture message data
*/
  private void setUpMessages() {

    iMessagedlg = new JDialog(this, "Messages", true); // modal popup.
    iMessagedlg.setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);

    JPanel dlgContents = new JPanel();
    iMessagedlg.getContentPane().add(dlgContents);
    dlgContents.setBorder(
                        BorderFactory.createEmptyBorder(10,10,10,10));
    dlgContents.setLayout(new BorderLayout());

    JPanel key = new JPanel();
    key.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
    key.setLayout(new GridLayout(1, 5, 5, 5));
    dlgContents.add(key, BorderLayout.NORTH);

    key.add(new JLabel("Message Number"));
    key.add(new JLabel("Message length/src"));
    key.add(new JLabel("Acceptable Time"));
    key.add(new JLabel("Failure Time"));
    key.add(new JLabel("Pace Time"));

    int msgNumbers = getNumberOfMesages();
    JPanel messageParms = new JPanel();
    JScrollPane scrPane = new JScrollPane();
    scrPane.getViewport().add(messageParms);
    dlgContents.add(scrPane);
    messageParms.setLayout(new GridLayout(msgNumbers, 5, 5, 5));

    // Instantiate the array of parameters only if the number 
    // requested has changed
    if (iMessageLenthOrFile == null || iMessageLenthOrFile.length 
                                                   != msgNumbers) {
      iMessageLenthOrFile = new JTextField [msgNumbers];
      iAcceptableTime = new JTextField [msgNumbers];
      iFailureTime = new JTextField [msgNumbers];
      iPaceTime = new JTextField [msgNumbers];
    }

    for (int i = 0; i < msgNumbers; i++) {

      messageParms.add(new JLabel(Integer.toString(i + 1) + "."));
      if (iMessageLenthOrFile[i] == null) iMessageLenthOrFile[i] 
                                                   = new JTextField();
      messageParms.add(iMessageLenthOrFile[i]);
      if (iAcceptableTime[i] == null) iAcceptableTime[i] 
                                                   = new JTextField();
      messageParms.add(iAcceptableTime[i]);
      if (iFailureTime[i] == null) iFailureTime[i] = new JTextField();
      messageParms.add(iFailureTime[i]);
      if (iPaceTime[i] == null) iPaceTime[i] = new JTextField();
      messageParms.add(iPaceTime[i]);
    }


